@@ -1,14 +1,14 @@
 package Complete::Unix;
 
-our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2015-09-09'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 #use Log::Any '$log';
 
-use Complete;
+use Complete::Setting;
 
 require Exporter;
 our @ISA = qw(Exporter);
@@ -52,7 +52,7 @@ sub complete_uid {
 
     my %args  = @_;
     my $word  = $args{word} // "";
-    my $ci    = $args{ci} // $Complete::OPT_CI;
+    my $ci    = $args{ci} // $Complete::Setting::OPT_CI;
 
     my $res = Unix::Passwd::File::list_users(
         etc_dir=>$args{etc_dir}, detail=>1);
@@ -80,7 +80,7 @@ sub complete_user {
 
     my %args  = @_;
     my $word  = $args{word} // "";
-    my $ci    = $args{ci} // $Complete::OPT_CI;
+    my $ci    = $args{ci} // $Complete::Setting::OPT_CI;
 
     my $res = Unix::Passwd::File::list_users(
         etc_dir=>$args{etc_dir}, detail=>1);
@@ -108,7 +108,7 @@ sub complete_gid {
 
     my %args  = @_;
     my $word  = $args{word} // "";
-    my $ci    = $args{ci} // $Complete::OPT_CI;
+    my $ci    = $args{ci} // $Complete::Setting::OPT_CI;
 
     my $res = Unix::Passwd::File::list_groups(
         etc_dir=>$args{etc_dir}, detail=>1);
@@ -136,7 +136,7 @@ sub complete_group {
 
     my %args  = @_;
     my $word  = $args{word} // "";
-    my $ci    = $args{ci} // $Complete::OPT_CI;
+    my $ci    = $args{ci} // $Complete::Setting::OPT_CI;
 
     my $res = Unix::Passwd::File::list_groups(
         etc_dir=>$args{etc_dir}, detail=>1);
@@ -163,7 +163,7 @@ sub complete_pid {
 
     my %args  = @_;
     my $word  = $args{word} // "";
-    my $ci    = $args{ci} // $Complete::OPT_CI;
+    my $ci    = $args{ci} // $Complete::Setting::OPT_CI;
 
     Complete::Util::complete_array_elem(
         array=>Proc::Find::find_proc(),
@@ -188,7 +188,7 @@ sub complete_proc_name {
 
     my %args  = @_;
     my $word  = $args{word} // "";
-    my $ci    = $args{ci} // $Complete::OPT_CI;
+    my $ci    = $args{ci} // $Complete::Setting::OPT_CI;
 
     Complete::Util::complete_array_elem(
         array=>[List::MoreUtils::uniq(
@@ -213,7 +213,7 @@ Complete::Unix - Unix-related completion routines
 
 =head1 VERSION
 
-This document describes version 0.04 of Complete::Unix (from Perl distribution Complete-Unix), released on 2015-09-03.
+This document describes version 0.05 of Complete::Unix (from Perl distribution Complete-Unix), released on 2015-09-09.
 
 =head1 DESCRIPTION
 
